FloatyProxyDisconnectedException constructor

const FloatyProxyDisconnectedException(
  1. String service,
  2. String method
)

Thrown when a proxy call is attempted while the main app is disconnected.

This avoids a full timeout wait when the main app is known to be unavailable. Use the optional fallback parameter on FloatyProxyClient.call to provide a default value instead of throwing.

Implementation

const FloatyProxyDisconnectedException(String service, String method)
    : super(
        'Main app is disconnected — '
        'cannot call $service.$method',
      );