FloatyProxyErrorException class

Thrown when the host-side handler threw an exception.

Inheritance

Constructors

FloatyProxyErrorException(String message)
Thrown when the host-side handler threw an exception.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
Description of the failure.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited