FloatyProxyException class abstract

Base exception for proxy call failures.

Implemented types
Implementers

Constructors

FloatyProxyException(String message)
Base exception for proxy call failures.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
Description of the failure.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited