setState method
Replaces the entire state and syncs to the other side.
Implementation
Future<void> setState(S newState) {
_state = newState;
return FloatyChannel.sendSystem(_prefix, {
'full': true,
'data': _toJson(newState),
});
}
Replaces the entire state and syncs to the other side.
Future<void> setState(S newState) {
_state = newState;
return FloatyChannel.sendSystem(_prefix, {
'full': true,
'data': _toJson(newState),
});
}