AddChatHeadConfig class

Configuration for adding a chathead bubble to an existing group.

Constructors

AddChatHeadConfig({required String id, String? iconAsset, IconSource? iconSource})
Configuration for adding a chathead bubble to an existing group.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
iconAsset String?
Flutter asset path for the bubble's icon.
final
iconSource IconSource?
Multi-source icon for the bubble.
final
id String
Unique identifier for this bubble.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited