addChatHead method
Adds a new chathead bubble to the existing group.
Implementation
@override
Future<void> addChatHead(AddChatHeadConfig config) async {
lastAddConfig = config;
}
Adds a new chathead bubble to the existing group.
@override
Future<void> addChatHead(AddChatHeadConfig config) async {
lastAddConfig = config;
}