expandChatHead method

  1. @override
Future<void> expandChatHead()
override

Programmatically expands the chathead to show its content panel.

Has no effect if the chathead is already expanded. Android only.

Implementation

@override
Future<void> expandChatHead() async {}