emitData method
Simulates the main app sending data to the overlay.
Implementation
void emitData(Object? data) => dataController.add(data);
Simulates the main app sending data to the overlay.
void emitData(Object? data) => dataController.add(data);