sendData method
Records data that would be sent to the main app.
Implementation
void sendData(Object? data) {
lastSentData = data;
sentData.add(data);
}
Records data that would be sent to the main app.
void sendData(Object? data) {
lastSentData = data;
sentData.add(data);
}