FloatyProxyDisconnectedException class
Thrown when a proxy call is attempted while the main app is disconnected.
This avoids a full timeout wait when the main app is known to be
unavailable. Use the optional fallback parameter on
FloatyProxyClient.call to provide a default value instead of
throwing.
- Inheritance
-
- Object
- FloatyProxyException
- FloatyProxyDisconnectedException
Constructors
- FloatyProxyDisconnectedException(String service, String method)
-
Thrown when a proxy call is attempted while the main app is
disconnected.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited